
public class LibRS232 {

	private native byte[] FindPort();
	private native int OpenPort(String str);
	private native int ConfigurePort(int baud);	
	private native int SendByte(byte[] b, int write_size);
	private native byte[] ReadByte(int read_size);
	private native int Event();
	private native int Purge();
	
	
	public LibRS232(){
	}
	
	/**
	 * Funcin que busca los puertos que hay en la PC.
	 * @return Byte array con los puertos COM disponibles en la computadora
	 */
	public byte[] RS232EncuentraPuertos(){
		return FindPort();
	}
	
	/**
	 Funcin que abre un puerto determinado.
	 @param str El puerto escrito como COM seguido del nmero. P/E COM14
	 @return Si el puerto se abre correctamente enva un 0.
	 */
	public int RS232AbrirPuerto(String str){
		return OpenPort(str);
	}
	/**
	 Configura velocidad en BAUDIOS
	 @param baud La velocidad de los BAUDIOS en tipo entero
	 @return 0 si se configura con exito
	 */
	public int RS232ConfigurarPuerto(int baud){
		return ConfigurePort(baud);
	}
	
	/**
	 Escribe el nmero de bytes dado por wSize almacenado en el array b.
	 @param b Array donde estn almacenados los bytes a enviar
	 @param wSize el nmero de bytes que quieres envair
	 */
	public int RS232EnviaBytes(byte[] b /** array*/, int wSize){
		
		return SendByte(b,wSize);
	}
	
	/**
	 Lee un nmero de bytes y los guarda en array.
	 @param rSize El nmero de bytes que se van a leer
	 @return array de bytes (byte[]) leidos
	 */
	public byte[] RS232LeerBytes(int rSize){
		return ReadByte(rSize);
	}
	
	/**
	Puede llamarse si ha ocurrido un evento de lectura
	 */
	public int RS232Evento(){
		return Event();
	}
	
	/**
	 Limpia el Buffer de entrada
	 */
	public int RS232Flush(){
		return Purge();
	}

	
	static{
		
		System.loadLibrary("libIntescRS232");
	}
	
}
